@@ -11,7 +11,7 @@ def getSoup(site):
 	for tag in offtopic_tags:
 		for item in soup.find_all(tag):
 			item.decompose()
-	for item in soup.find_all():
-		if item.attrs and matchKey(str(item.attrs), ['footer', 'bg-grey-lighter']):
+	if 'freewechat.com' in site:
+		for item in soup.find_all('div', id='hot-articles'):
 			item.decompose()
 	return soup
\ No newline at end of file
