@@ -8,25 +8,14 @@ def isYear(part):
 		...
 	return False
 
-def hasYear(parts):
-	for part in parts:
+def containYear(link):
+	for part in link.split('/'):
 		if isYear(part):
 			return True
 	return False
 
-def _hasNumber(part):
-	if not part:
-		return False
-	part = part.split('-')[-1]
-	try:
-		int(part)
-		return True
-	except:
-		...
-	return False
-
-def hasNumber(parts):
-	for part in parts:
-		if _hasNumber(part):
+def hasSignature(link, sig_len):
+	for length in sig_len:
+		if link[-length:][:1] == '-':
 			return True
 	return False
\ No newline at end of file
